//-------------------------------------------------------------------
// ECLField.IsModified
// ECLField.IsProtected
// ECLField.IsNumeric
// ECLField.IsHighIntensity
// ECLField.IsPenDetectable
// ECLField.IsDisplay
//
// Iterate over list of fields and print each field's attributes.
//-------------------------------------------------------------------
import java.util.Properties;
import com.ibm.eNetwork.ECL.*;

public class Sample37 implements ECLAppletInterface
{

   /*********************************************************************
   * Constructor
   */
   public Sample37()
   {
   }


   /*********************************************************************
   * Method called by Host On-Demand when the applet is initialized.
   * This method is defined as part of the ECLAppletInterface
   */
   public void init(ECLSession s)
   {

       ECLPS        ps;           // PS object
       ECLFieldList fieldList;    // field list object
       ECLField     field;        // field object

       ps = s.GetPS();            // Get instance of ECLPS

       try {
          fieldList = ps.GetFieldList(ECLFieldList.ALL_PLANES);                   // Get field list

          for (field = fieldList.GetFirstField(ECLFieldList.ALL_FIELDS);          // First field
               field != null;                                                     // While more
               field = fieldList.GetNextField(field, ECLFieldList.ALL_FIELDS)) {  // Next field

              System.out.print("Field at " + formatString(field.GetStartRow(),2,0) + ","+ formatString(field.GetStartCol(),3,0) + " is: ");

              if (field.IsProtected())
                System.out.print("Protect ");
              else
                System.out.print("Input   ");

              if (field.IsModified())
                System.out.print("Modified   ");
              else
                System.out.print("Unmodified ");

              if (field.IsNumeric())
                System.out.print("Numeric  ");
              else
                System.out.print("Alphanum ");

              if (field.IsHighIntensity())
                System.out.print("HiIntensity ");
              else
                System.out.print("Normal      ");

              if (field.IsPenDetectable())
                System.out.print("Penable ");
              else
                System.out.print("NoPen   ");

              if (field.IsDisplay())
                System.out.println("Display ");
              else
                System.out.println("Hidden  ");
          }
       } catch (ECLErr e) { System.out.println("Sample37(): " + e.GetMsgText()); }

   } // end sample

   // Utility method used to format strings
   private String formatString(int num, int length, int justify)
   {
     String numString = String.valueOf(num);
     int numLength = numString.length();
     StringBuffer retBuffer = new StringBuffer();

     if (numLength == length)
        return numString.toString();
     if (numLength > length)
        return numString.toString().substring(0,length);

     if (justify == 0)  // right justify
     {
        for (int i = length; numLength < i; i--)
           retBuffer.append('0');

        retBuffer.append(numString);
     }
     else               // left justify
     {
        retBuffer.append(numString);

        for (int i = length; numLength < i; i--)
           retBuffer.append(' ');
     }


     return retBuffer.toString();
   }

}
